@@ -55,7 +55,7 @@ class Update:
             "GUID",
             "FirstName",
             "LastName",
-            # "MiddleName",
+            "MiddleName",
             "LegalName",
             "PersonnelType",
             "PID",
@@ -104,7 +104,6 @@ class Update:
                     "disabled",
                     "guid",
                     "id",
-                    "middle_name",
                     "personnel_type_id",
                     "personnel_type_name",
                 ]:
@@ -332,7 +331,9 @@ class Update:
             worker_sub_type = p["worker_sub_type"]
 
             p["company"] = ""
-            p["disabled"] = p["terminated"]
+            # p["disabled"] = p["terminated"]
+            if "disabled" in p:
+                del p["disabled"]
             # p["first_name"] = p["first_name_ascii"]
             # p["home_institution"] = p["home_institution_ascii"]
             # p["last_name"] = p["last_name_ascii"]
@@ -444,63 +445,44 @@ class Update:
         """Prepare data for newpersonnel.csv."""
         entries = []
         for p in newpersonnel:
-            entry = {
-                "ObjectID": None,
-                "GUID": None,
-                "FirstName": p["first_name"],
-                "LastName": p["last_name"],
-                # "MiddleName": "",
-                "LegalName": p["legal_name"],
-                "PersonnelType": p["personnel_type_name"],
-                "PID": p["person_id"],
-                "EMPLID": p["emplid"],
-                "Username": p["username"],
-                "Email": p["email"],
-                "AccessLevel": None,
-                "HomeInstitution": p["home_institution"],
-                "DepartmentName": p["department_name"],
-                "SupervisorName": p["supervisor_name"],
-                "Title": p["title"],
-                "WorkerType": p["worker_type"],
-                "OrgUnit": p["org_unit"],
-                "Desk": p["desk"],
-                "Parking": p["parking"],
-                "Status": p["status"],
-                "ActivationDateTime": p["activation_datetime"],
-                "ExpirationDateTime": p["expiration_datetime"],
-            }
+            entry = self.prepare_person(p)
             entries.append(entry)
         return entries
 
+    def prepare_person(self, p):
+        """Prepare a single personnel record."""
+        entry = {
+            "ObjectID": p.get("id"),
+            "GUID": p.get("guid"),
+            "FirstName": p["first_name"],
+            "LastName": p["last_name"],
+            "MiddleName": "",
+            "LegalName": p["legal_name"],
+            "PersonnelType": p["personnel_type_name"],
+            "PID": p["person_id"],
+            "EMPLID": p["emplid"],
+            "Username": p["username"],
+            "Email": p["email"],
+            "AccessLevel": None,
+            "HomeInstitution": p["home_institution"],
+            "DepartmentName": p["department_name"],
+            "SupervisorName": p["supervisor_name"],
+            "Title": p["title"],
+            "WorkerType": p["worker_type"],
+            "OrgUnit": p["org_unit"],
+            "Desk": p["desk"],
+            "Parking": p["parking"],
+            "Status": p["status"],
+            "ActivationDateTime": p["activation_datetime"],
+            "ExpirationDateTime": p["expiration_datetime"],
+        }
+        return entry
+
     def prepare_personnel(self, personnel):
         """Prepare data fro personnel.csv."""
         entries = []
         for p in personnel:
-            entry = {
-                "ObjectID": p["id"],
-                "GUID": p["guid"],
-                "FirstName": p["first_name"],
-                "LastName": p["last_name"],
-                # "MiddleName": "",
-                "LegalName": p["legal_name"],
-                "PersonnelType": p["personnel_type_name"],
-                "PID": p["person_id"],
-                "EMPLID": p["emplid"],
-                "Username": p["username"],
-                "Email": p["email"],
-                "AccessLevel": None,
-                "HomeInstitution": p["home_institution"],
-                "DepartmentName": p["department_name"],
-                "SupervisorName": p["supervisor_name"],
-                "Title": p["title"],
-                "WorkerType": p["worker_type"],
-                "OrgUnit": p["org_unit"],
-                "Desk": p["desk"],
-                "Parking": p["parking"],
-                "Status": p["status"],
-                "ActivationDateTime": p["activation_datetime"],
-                "ExpirationDateTime": p["expiration_datetime"],
-            }
+            entry = self.prepare_person(p)
             entries.append(entry)
         return entries
 
